@@ -1,6 +1,6 @@
 package Transform::Alert::Input::IMAP;
 
-our $VERSION = '0.92'; # VERSION
+our $VERSION = '0.93'; # VERSION
 # ABSTRACT: Transform alerts from IMAP messages
 
 use sanity;
@@ -9,6 +9,7 @@ use MooX::Types::MooseLike::Base qw(Str ArrayRef InstanceOf);
 
 use Mail::IMAPClient;
 use Email::MIME;
+use List::AllUtils 'first';
 
 with 'Transform::Alert::Input';
 
@@ -89,7 +90,10 @@ sub get {
    my $msg = $imap->message_string($uid) || do { $self->log->error('Error grabbing IMAP message '.$uid.': '.$imap->LastError); return; };
    $msg =~ s/\r//g;
    my $pmsg = Email::MIME->new($msg);
-   my $body = $pmsg->body_str;
+   my $body = eval { $pmsg->body_str } || do {
+      my $part = first { $_ && $_->content_type =~ /^text\/plain/ } $pmsg->parts;
+      $part ? $part->body_str : $pmsg->body_raw;
+   };
    $body =~ s/\r//g;
    my $hash = {
       $pmsg->header_obj->header_pairs,
@@ -170,7 +174,7 @@ figure out which messages have been parsed or not parsed.
 
 =head2 Text
 
-Full text of the message, including headers.  All CRs are stripped.
+Full text of the raw message, including headers.  All CRs are stripped.
 
 =head2 Preparsed Hash
 
@@ -178,9 +182,10 @@ Full text of the message, including headers.  All CRs are stripped.
        # Header pairs, as per Email::Simple::Header
        Email::Simple->new($msg)->header_obj->header_pairs,
  
-       # decoded via Email::MIME->new($msg)->body_str
+       # decoded via Email::MIME->new($msg)
+       # $pmsg->body_str, or body_str of the first text/plain part (if it croaks), or $pmsg->body_raw
        # (all \r are stripped)
-       BODY => $str,  
+       BODY => $str,
     }
 
 =head1 CAVEATS
@@ -188,6 +193,9 @@ Full text of the message, including headers.  All CRs are stripped.
 You are responsible for setting up any archivingE<sol>deletion protocols for the mailbox, as this module will save everything (and potentially
 fill up the box).
 
+The raw message isn't kept for the Munger.  If you really need it, you can implement an input RE template of C<<< (?<RAWMSG>[\s\S]+) >>>, and parse
+out the email message yourself.
+
 This class is persistent, keeping the L<Mail::IMAPClient> object until shutdown.  However, it will still disconnect on close.
 
 =head1 AVAILABILITY
